cheesecake.cheesecake_index.NameSetter

Package cheesecake :: Module cheesecake_index :: Class NameSetter |
[hide private]
[frames] | no frames]

## Type NameSetter
source code

    object --+
             |
          type --+
                 |
                NameSetter

Instance Methods | [hide private]
| __init__(cls, name, bases, dict) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| __repr__(cls) repr(x)
Inherited from `type`: `__call__`, `__cmp__`, `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__setattr__`, `__subclasses__`, `mro` Inherited from `object`: `__reduce__`, `__reduce_ex__`, `__str__`

Class Variables | [hide private]
Inherited from `type`: `__base__`, `__bases__`, `__basicsize__`, `__dictoffset__`, `__flags__`, `__itemsize__`, `__mro__`, `__name__`, `__weakrefoffset__` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(cls, name, bases, dict) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(cls) (Representation operator) | source code
repr(x) Overrides: type.__repr__ (inherited documentation)